kurbopy
=======

Kurbopy is a Python wrapper around the Rust `kurbo <https://github.com/linebender/kurbo>`_
library, a 2D curve manipulation library with "a focus on accuracy and good
performance in high-accuracy conditions".


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   common
   affine
   arc
   bezpath
   circle
   constpoint
   cubicbez
   ellipse
   insets
   line
   mindistance
   pathseg
   point
   quadbez
   quadspline
   rect
   size
   translatescale
   vec2

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
